@@ -12,9 +12,6 @@ class OSTools:
         time.sleep(0.01)
         print(header)
 
-    def FileSlash():
-        return "/" if platform.system() != "Windows" else "\\"
-
     def WaitOnDownload(filNam, loc):
         downloadPath = os.getcwd()
         downloadPath += ost.FileSlash() + loc + ost.FileSlash()
@@ -77,13 +74,12 @@ class OSTools:
 
 
 class SeleniumTools:
-    def GetNewWebdriver(loc, vis):
+    def GetNewWebdriver(locPath, vis):
         option = webdriver.ChromeOptions()
         downloadPath = os.getcwd()
         prefs = {
             "profile.default_content_setting_values.automatic_downloads": 1,
-            "download.default_directory": downloadPath
-            + (ost.FileSlash() + loc + ost.FileSlash()),
+            "download.default_directory": downloadPath + locPath,
         }
         if not vis:
             option.add_argument("--no-sandbox")
